from setuptools import setup

setup(name='distributions_test',
      version='0.1.1',
      description='Gaussian and Binomial distributions ',
      packages=['distributions'],
      zip_safe=False)
